@@ -9,12 +9,12 @@ import (
 	. "github.com/onsi/ginkgo/extensions/table"
 	. "github.com/onsi/gomega"
 	"github.com/pkg/errors"
-	"github.com/weaveworks/eksctl/pkg/utils"
 
 	"github.com/weaveworks/eksctl/integration/tests"
 	api "github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5"
 	"github.com/weaveworks/eksctl/pkg/eks"
 	"github.com/weaveworks/eksctl/pkg/testutils"
+	instanceutils "github.com/weaveworks/eksctl/pkg/utils/instance"
 
 	. "github.com/onsi/ginkgo"
 )
@@ -58,7 +58,7 @@ var _ = Describe("(Integration) [Instance Selector test]", func() {
 	},
 		Entry("non-GPU instances", func(instanceTypes []string) {
 			for _, instanceType := range instanceTypes {
-				Expect(instanceType).ToNot(Satisfy(utils.IsGPUInstanceType))
+				Expect(instanceType).ToNot(Satisfy(instanceutils.IsGPUInstanceType))
 			}
 		}, "--instance-selector-vcpus=8",
 			"--instance-selector-memory=32",
